/******************************************************************************
 * Toggle_Command - Client toggles an attribute
 * $Id: Toggle_Command.java,v 1.6 2011/06/09 18:19:18 dick Exp $
 * 
 * jIBS - A Java clone of FIBS
 * Copyright 2002 - Axel Leucht
 * Copyright 2011 - Dick Balaska - BuckoSoft, Corp.
 * 
 * $Log: Toggle_Command.java,v $
 * Revision 1.6  2011/06/09 18:19:18  dick
 * Use Player.println() instead of the JibsWriter.
 *
 * Revision 1.5  2011/06/06 03:18:26  dick
 * JibsMessages belongs in n.s.jibs.server, not n.s.jibs.gui
 *
 * Revision 1.4  2011/06/06 02:56:33  dick
 * Switch the state of the echoed back double is on/off messages.
 *
 * Revision 1.3  2011/06/05 20:26:02  dick
 * toggle silent messages were backwards.
 *
 * Revision 1.2  2011/05/31 13:02:43  dick
 * Bucko headers.
 *
 */

/* 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * The Original Code is jIBS, <https://sourceforge.net/projects/fibs/>.
 * The Initial Developer of the Original Code is Axel Leucht.
 * 
 */
package net.sourceforge.jibs.command;

import net.sourceforge.jibs.server.JibsMessages;
import net.sourceforge.jibs.server.JibsServer;
import net.sourceforge.jibs.server.Player;
import net.sourceforge.jibs.util.JibsToggle;

/** Client toggles an attribute.
 *
 * @author Axel Leucht
 * @author Dick Balaska
 * @version $Revision: 1.6 $ <br> $Date: 2011/06/09 18:19:18 $
 * @see <a href="http://cvs.buckosoft.com/Projects/jIBS/jIBS/src/main/java/net/sourceforge/jibs/command/Toggle_Command.java">cvs Toggle_Command.java</a>
 */
public class Toggle_Command implements JibsCommand {

	@Override
	public boolean execute(JibsServer jibsServer, Player player,
			String strArgs, String[] args) {
		String[] toggleMap = new String[] {
				"allowpip", "autoboard", "autodouble",
				"automove", "bell", "crawford", "double",
				"greedy", "moreboards", "moves", "notify",
				"ratings", "ready", "report", "silent",
				"telnet", "wrap"
		};
		JibsMessages jibsMessages = jibsServer.getJibsMessages();
		JibsToggle jibsToggle = player.getJibsToggles();

		if (args.length <= 1) {
			player.println("The current settings are:");

			for (int i = 0; i < toggleMap.length; i++) {
				String key = toggleMap[i];
				Boolean value = jibsToggle.get(key);
				StringBuffer sBuffer = new StringBuffer();
				StringBuffer sKey = new StringBuffer();

				sKey.append(key);
				sKey.append("        ");
				sBuffer.append(sKey.toString().substring(0, 12));
				sBuffer.append("\t");

				if (value.booleanValue() == true) {
					sBuffer.append("YES");
				} else {
					sBuffer.append("NO");
				}

				player.println(sBuffer.toString());
			}
		}

		for (int i = 1; i < args.length; i++) {
			String key = args[i];
			int mode = Toggle_Command.mapToggle(toggleMap, key);
			String msg = null;
			Boolean value = null;
			boolean newValue = false;

			switch (mode) {
			case 0: // allowpip
			value = jibsToggle.get(key);
			newValue = !value.booleanValue();
			jibsToggle.set(key, Boolean.valueOf(newValue));

			if (newValue == true) {
				msg = jibsMessages.convert("m_toggle_allowpip_on");
				player.println(msg);
			} else {
				msg = jibsMessages.convert("m_toggle_allowpip_off");
				player.println(msg);
			}

			break;

			case 1: // autoboard
				value = jibsToggle.get(key);
				newValue = !value.booleanValue();
				jibsToggle.set(key, Boolean.valueOf(newValue));

				if (newValue == true) {
					msg = jibsMessages.convert("m_toggle_autoboard_on");
					player.println(msg);
				} else {
					msg = jibsMessages.convert("m_toggle_autoboard_off");
					player.println(msg);
				}

				break;

			case 2: // autodouble
				value = jibsToggle.get(key);
				newValue = !value.booleanValue();
				jibsToggle.set(key, Boolean.valueOf(newValue));

				if (newValue == true) {
					msg = jibsMessages.convert("m_toggle_autodouble_on");
					player.println(msg);
				} else {
					msg = jibsMessages.convert("m_toggle_autodouble_off");
					player.println(msg);
				}

				break;

			case 3: // automove
				value = jibsToggle.get(key);
				newValue = !value.booleanValue();
				jibsToggle.set(key, Boolean.valueOf(newValue));

				if (newValue == true) {
					msg = jibsMessages.convert("m_toggle_automove_on");
					player.println(msg);
				} else {
					msg = jibsMessages.convert("m_toggle_automove_off");
					player.println(msg);
				}

				break;

			case 4: // bell
				value = jibsToggle.get(key);
				newValue = !value.booleanValue();
				jibsToggle.set(key, Boolean.valueOf(newValue));

				if (newValue == true) {
					msg = jibsMessages.convert("m_toggle_bell_on");
					player.println(msg);
				} else {
					msg = jibsMessages.convert("m_toggle_bell_off");
					player.println(msg);
				}

				break;

			case 5: // crawford
				value = jibsToggle.get(key);
				newValue = !value.booleanValue();
				jibsToggle.set(key, Boolean.valueOf(newValue));

				if (newValue == true) {
					msg = jibsMessages.convert("m_toggle_crawford_on");
					player.println(msg);
				} else {
					msg = jibsMessages.convert("m_toggle_crawford_off");
					player.println(msg);
				}

				break;

			case 6: // double
				value = jibsToggle.get(key);
				newValue = !value.booleanValue();
				jibsToggle.set(key, Boolean.valueOf(newValue));

				if (newValue == true) {
					msg = jibsMessages.convert("m_toggle_double_on");
					player.println(msg);
				} else {
					msg = jibsMessages.convert("m_toggle_double_off");
					player.println(msg);
				}

				break;

			case 7: // greedy
				value = jibsToggle.get(key);
				newValue = !value.booleanValue();
				jibsToggle.set(key, Boolean.valueOf(newValue));

				if (newValue == true) {
					msg = jibsMessages.convert("m_toggle_greedy_on");
					player.println(msg);
				} else {
					msg = jibsMessages.convert("m_toggle_greedy_off");
					player.println(msg);
				}

				break;

			case 8: // moreboards
				value = jibsToggle.get(key);
				newValue = !value.booleanValue();
				jibsToggle.set(key, Boolean.valueOf(newValue));

				if (newValue == true) {
					msg = jibsMessages.convert("m_toggle_moreboards_on");
					player.println(msg);
				} else {
					msg = jibsMessages.convert("m_toggle_moreboards_off");
					player.println(msg);
				}

				player.informWhoinfoChange();

				break;

			case 9: // moves
				value = jibsToggle.get(key);
				newValue = !value.booleanValue();
				jibsToggle.set(key, Boolean.valueOf(newValue));

				if (newValue == true) {
					msg = jibsMessages.convert("m_toggle_moves_on");
					player.println(msg);
				} else {
					msg = jibsMessages.convert("m_toggle_moves_off");
					player.println(msg);
				}

				break;

			case 10: // notify
				value = jibsToggle.get(key);
				newValue = !value.booleanValue();
				jibsToggle.set(key, Boolean.valueOf(newValue));

				if (newValue == true) {
					msg = jibsMessages.convert("m_toggle_notify_on");
					player.println(msg);
				} else {
					msg = jibsMessages.convert("m_toggle_notify_off");
					player.println(msg);
				}

				break;

			case 11: // ratings
				value = jibsToggle.get(key);
				newValue = !value.booleanValue();
				jibsToggle.set(key, Boolean.valueOf(newValue));

				if (newValue == true) {
					msg = jibsMessages.convert("m_toggle_ratings_on");
					player.println(msg);
				} else {
					msg = jibsMessages.convert("m_toggle_ratings_off");
					player.println(msg);
				}

				break;

			case 12: // ready
				value = jibsToggle.get(key);
				newValue = !value.booleanValue();
				jibsToggle.set(key, Boolean.valueOf(newValue));

				if (newValue == true) {
					msg = jibsMessages.convert("m_toggle_ready_on");
					player.println(msg);
				} else {
					msg = jibsMessages.convert("m_toggle_ready_off");
					player.println(msg);
				}

				player.informWhoinfoChange();

				break;

			case 13: // report
				value = jibsToggle.get(key);
				newValue = !value.booleanValue();
				jibsToggle.set(key, Boolean.valueOf(newValue));

				if (newValue == true) {
					msg = jibsMessages.convert("m_toggle_report_on");
					player.println(msg);
				} else {
					msg = jibsMessages.convert("m_toggle_report_off");
					player.println(msg);
				}

				break;

			case 14: // silent
				value = jibsToggle.get(key);
				newValue = !value.booleanValue();
				jibsToggle.set(key, Boolean.valueOf(newValue));

				if (newValue == true) {
					msg = jibsMessages.convert("m_toggle_silent_off");
					player.println(msg);
				} else {
					msg = jibsMessages.convert("m_toggle_silent_on");
					player.println(msg);
				}

				break;

			case 15: // telnet
				value = jibsToggle.get(key);
				newValue = !value.booleanValue();
				jibsToggle.set(key, Boolean.valueOf(newValue));

				if (newValue == true) {
					msg = jibsMessages.convert("m_toggle_telnet_on");
					player.println(msg);
				} else {
					msg = jibsMessages.convert("m_toggle_telnet_off");
					player.println(msg);
				}

				break;

			case 16: // wrap
				value = jibsToggle.get(key);
				newValue = !value.booleanValue();
				jibsToggle.set(key, Boolean.valueOf(newValue));

				if (newValue == true) {
					msg = jibsMessages.convert("m_toggle_wrap_on");
					player.println(msg);
				} else {
					msg = jibsMessages.convert("m_toggle_wrap_off");
					player.println(msg);
				}

				break;

			default:

				// m_toggle_unknown** Don't know how to toggle %0
				Object[] obj = new Object[] { key };
				msg = jibsMessages.convert("m_toggle_unknown", obj);
				player.println(msg);

				break;
			}
		}

		return true;
	}

	private static int mapToggle(String[] toggleMap, String key) {
		for (int i = 0; i < toggleMap.length; i++) {
			if (toggleMap[i].equals(key)) {
				return i;
			}
		}

		return -1;
	}
}
